Index: main/logger.c
===================================================================
--- main/logger.c	(revision 43538)
+++ main/logger.c	(working copy)
@@ -85,6 +85,7 @@
 
 static int filesize_reload_needed = 0;
 static int global_logmask = -1;
+static int rotatetimestamp = 0;
 
 static struct {
 	unsigned int queue_log:1;
@@ -336,6 +337,8 @@
 		logfiles.queue_log = ast_true(s);
 	if ((s = ast_variable_retrieve(cfg, "general", "event_log")))
 		logfiles.event_log = ast_true(s);
+	if ((s = ast_variable_retrieve(cfg, "general", "rotatetimestamp")))
+		rotatetimestamp = 1;
 
 	AST_LIST_LOCK(&logchannels);
 	var = ast_variable_browse(cfg, "logfiles");
@@ -401,15 +404,18 @@
 			if (rotate) {
 				ast_copy_string(old, f->filename, sizeof(old));
 	
-				for (x = 0; ; x++) {
-					snprintf(new, sizeof(new), "%s.%d", f->filename, x);
-					myf = fopen((char *)new, "r");
-					if (myf)
-						fclose(myf);
-					else
-						break;
-				}
-	    
+				if (!rotatetimestamp) { 
+					for (x = 0; ; x++) {
+						snprintf(new, sizeof(new), "%s.%d", f->filename, x);
+						myf = fopen((char *)new, "r");
+						if (myf)
+							fclose(myf);
+						else
+							break;
+					}
+				} else 
+					snprintf(new, sizeof(new), "%s.%ld", f->filename, (long)time(NULL));
+
 				/* do it */
 				if (rename(old,new))
 					fprintf(stderr, "Unable to rename file '%s' to '%s'\n", old, new);
@@ -424,14 +430,17 @@
 	if (logfiles.event_log) {
 		snprintf(old, sizeof(old), "%s/%s", (char *)ast_config_AST_LOG_DIR, EVENTLOG);
 		if (event_rotate) {
-			for (x=0;;x++) {
-				snprintf(new, sizeof(new), "%s/%s.%d", (char *)ast_config_AST_LOG_DIR, EVENTLOG,x);
-				myf = fopen((char *)new, "r");
-				if (myf) 	/* File exists */
-					fclose(myf);
-				else
-					break;
-			}
+			if (!rotatetimestamp) { 
+						for (x = 0; ; x++) {
+							snprintf(new, sizeof(new), "%s/%s.%d", (char *)ast_config_AST_LOG_DIR, EVENTLOG,x);
+							myf = fopen((char *)new, "r");
+							if (myf) 	/* File exists */
+								fclose(myf);
+							else
+								break;
+						}
+			} else 
+				snprintf(new, sizeof(new), "%s/%s.%ld", (char *)ast_config_AST_LOG_DIR, EVENTLOG,(long)time(NULL));
 	
 			/* do it */
 			if (rename(old,new))
@@ -452,15 +461,18 @@
 	if (logfiles.queue_log) {
 		snprintf(old, sizeof(old), "%s/%s", (char *)ast_config_AST_LOG_DIR, QUEUELOG);
 		if (queue_rotate) {
-			for (x = 0; ; x++) {
-				snprintf(new, sizeof(new), "%s/%s.%d", (char *)ast_config_AST_LOG_DIR, QUEUELOG, x);
-				myf = fopen((char *)new, "r");
-				if (myf) 	/* File exists */
-					fclose(myf);
-				else
-					break;
-			}
+			if (!rotatetimestamp) { 
+				for (x = 0; ; x++) {
+					snprintf(new, sizeof(new), "%s/%s.%d", (char *)ast_config_AST_LOG_DIR, QUEUELOG, x);
+					myf = fopen((char *)new, "r");
+					if (myf) 	/* File exists */
+						fclose(myf);
+					else
+						break;
+				}
 	
+			} else 
+				snprintf(new, sizeof(new), "%s/%s.%ld", (char *)ast_config_AST_LOG_DIR, QUEUELOG,(long)time(NULL));
 			/* do it */
 			if (rename(old, new))
 				ast_log(LOG_ERROR, "Unable to rename file '%s' to '%s'\n", old, new);
Index: configs/logger.conf.sample
===================================================================
--- configs/logger.conf.sample	(revision 43538)
+++ configs/logger.conf.sample	(working copy)
@@ -16,6 +16,11 @@
 ; This appends the hostname to the name of the log files.
 ;appendhostname = yes
 ;
+; Rename the logfiles using a timestamp instead of a 
+; sequence number when "logger rotate" is executed
+; (defaults to no).
+;rotatetimestamp = yes
+;
 ; This determines whether or not we log queue events to a file
 ; (defaults to yes).
 ;queue_log = no
